@@ -1,5 +1,5 @@
 /*
- * $Id: ngrep.c,v 1.13 2001/04/22 23:27:16 jpr5 Exp $
+ * $Id: ngrep.c,v 1.14 2001/04/23 14:34:06 jpr5 Exp $
  *
  * Copyright (c) 2001  Jordan Ritter <jpr5@darkridge.com>
  *
@@ -62,7 +62,7 @@
 #include "ngrep.h"
 
 
-static char rcsver[] = "$Revision: 1.13 $";
+static char rcsver[] = "$Revision: 1.14 $";
 
 int snaplen = 65535, promisc = 1, to = 1000;
 int show_empty = 0, show_hex = 0, quiet = 0;
@@ -116,7 +116,7 @@ int main(int argc, char **argv) {
   signal(SIGPIPE, clean_exit);
   signal(SIGWINCH, update_windowsize);
 
-  while ((c = getopt(argc, argv, "hXViwqevxlDtTn:d:A:I:O:")) != EOF) {
+  while ((c = getopt(argc, argv, "hXViwqpevxlDtTn:d:A:I:O:")) != EOF) {
     switch (c) {
     case 'I':  
       read_file = optarg;
